@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Run Kwalitee tests including optional indicators, especially, prereq_matches_use
-our $VERSION = 'v0.0.8'; # VERSION
+our $VERSION = 'v0.1.0'; # VERSION
 
 use version 0.77;
 use Cwd;
@@ -18,6 +18,11 @@ use Module::CPANTS::Kwalitee::Prereq;
 use Module::CoreList;
 use Module::Extract::Namespaces;
 
+sub _exclude_proper_libs
+{
+	my $target_ver = version->parse($Module::CPANTS::Analyse::VERSION);
+	return $target_ver == version->parse('0.88') || $target_ver > version->parse('0.89');
+}
 
 sub _init
 {
@@ -29,6 +34,7 @@ sub _init
 			extracts_nicely => 1,
 			has_version => 1,
 			has_proper_version => 1,
+			_exclude_proper_libs() ? (proper_libs => 1) : (),
 
 		# already dirty in test phase
 			no_generated_files => 1,
@@ -55,6 +61,10 @@ sub _pmu_error_desc
 		($error, $remedy) = @{$val}{qw(error remedy)} if $val->{name} eq 'prereq_matches_use';
 		($berror, $bremedy) = @{$val}{qw(error remedy)} if $val->{name} eq 'build_prereq_matches_use';
 	}
+	$error   ||= q{This distribution uses a module or a dist that's not listed as a prerequisite.};
+	$remedy  ||= q{List all used modules in META.yml requires};
+	$berror  ||= q{This distribution uses a module or a dist in it's test suite that's not listed as a build prerequisite.};
+	$bremedy ||= q{List all modules used in the test suite in META.yml build_requires};
 
 	return ($error, $remedy, $berror, $bremedy);
 }
@@ -146,8 +156,8 @@ sub _do_test_pmu
 		my $result = $mcpan->module($key);
 		croak 'Query to MetaCPAN failed for $val->{requires}' if ! exists $result->{distribution};
 		my $dist = $result->{distribution};
-		push @missing, $key.' in '.$dist if $val->{in_code} && ! exists $prereq{$dist};
-		push @bmissing, $key.' in '.$dist if $val->{in_tests} && ! exists $build_prereq{$dist};
+		push @missing, $key.' in '.$dist if $val->{in_code} && $val->{in_code} != ($val->{evals_in_code} || 0) && ! exists $prereq{$dist};
+		push @bmissing, $key.' in '.$dist if $val->{in_tests} && $val->{in_tests} != ($val->{evals_in_tests} || 0) && ! exists $build_prereq{$dist};
 	}
 
 	_do_test_one($test, @missing == 0, 'prereq_matches_use by '.__PACKAGE__, $error, $remedy, 'Missing: '.join(', ', sort @missing))
@@ -335,7 +345,7 @@ Test::Kwalitee::Extra - Run Kwalitee tests including optional indicators, especi
 
 =head1 VERSION
 
-version v0.0.8
+version v0.1.0
 
 =head1 SYNOPSIS
 
@@ -360,34 +370,23 @@ version v0.0.8
 
 =head1 DESCRIPTION
 
-L<CPANTS|http://cpants.cpanauthors.org/> checks Kwalitee indicators, which is not quality 
-but automatically-measurable indicators how good your distribution is.
-L<Module::CPANTS::Analyse> calcluates Kwalitee but it is not directly applicable to your module test.
-CPAN has already had L<Test::Kwalitee> for the test module of Kwalitee.
-It is, however, limited to 13 indicators from 35 indicators (core and optional), as of 1.01.
-Furthermore, L<Module::CPANTS::Analyse> itself cannot calculate C<prereq_matches_use> indicator.
-It is marked as C<needs_db>, but only limited information is needed to calculate the indicator.
-This module calculate C<prereq_matches_use> to query needed information to L<MetaCPAN|https://metacpan.org/>.
+L<CPANTS|http://cpants.cpanauthors.org/> checks Kwalitee indicators, which is not quality but automatically-measurable indicators how good your distribution is. L<Module::CPANTS::Analyse> calcluates Kwalitee but it is not directly applicable to your module test. CPAN has already had L<Test::Kwalitee> for the test module of Kwalitee. It is, however, impossible to calculate C<prereq_matches_use> indicator, because dependent module L<Module::CPANTS::Analyse> itself cannot calculate C<prereq_matches_use> indicator. It is marked as C<needs_db>, but only limited information is needed to calculate the indicator. This module calculate C<prereq_matches_use> to query needed information to L<MetaCPAN|https://metacpan.org/>.
 
-Currently, 19 core indicators and 9 optional indicators are available in default configuration. See L</INDICATORS> section.
+For available indicators, see L</INDICATORS> section.
 
 =head1 OPTIONS
 
-You can specify including or excluding an indicator or a tag like L<Exporter>.
-Valid tags are C<core>, C<optional> and C<experimental>. For indicators, see L<Module::CPANTS::Analyse>.
+You can specify including or excluding an indicator or a tag like L<Exporter>. Valid tags are C<core>, C<optional> and C<experimental>. For indicators, see L<Module::CPANTS::Analyse>.
+
+Please NOTE that to specify tags are handled a bit differently from L<Exporter>. First, specifying an indicator is always superior to specifying tags, even though specifying an indicator is prior to specifying tags.
 
-Please NOTE that to specify tags are handled a bit differently from L<Exporter>.
-First, specifying an indicator is always superior to specifying tags, 
-even though specifying an indicator is prior to specifying tags.
 For example, 
 
   use Test::Kwalitee::Extra qw(!has_example :optional);
 
 C<!has_example> is in effect, that is C<has_exaple> is excluded, even though C<has_example> is an C<optional> indicator.
 
-Second, default excluded indicators mentioned in L</INDICATORS> section are not included by specifying tags.
-For example, in the above example, C<:optional> does not enable C<is_prereq>.
-You can override it by explicitly specifying the indicator:
+Second, default excluded indicators mentioned in L</INDICATORS> section are not included by specifying tags. For example, in the above example, C<:optional> does not enable C<is_prereq>. You can override it by explicitly specifying the indicator:
 
   use Test::Kwalitee::Extra qw(manifest_matches_dist);
 
@@ -397,28 +396,44 @@ Some tags have special meanings.
 
 =head2 C<:no_plan>
 
-If specified, do not call C<Test::Builder::plan>.
-You may need to specify it, if this test is embedded into other tests.
+If specified, do not call C<Test::Builder::plan>. You may need to specify it, if this test is embedded into other tests.
 
 =head2 C<:minperlver> <C<version>>
 
-C<prereq_matches_use> indicator ignores core modules.
-What modules are in core, however, is different among perl versions.
-If minimum perl version is specified in META.yml or such a meta information, it is used as minimum perl version.
-Otherewise, C<$]>, the version of the current perl interpreter, is used.
+C<prereq_matches_use> indicator ignores core modules. What modules are in core, however, is different among perl versions. If minimum perl version is specified in META.yml or such a meta information, it is used as minimum perl version. Otherewise, C<$]>, the version of the current perl interpreter, is used.
 
 If specified, this option overrides them.
 
 =head1 INDICATORS
 
-In L<Module::CPANTS::Analyse>, prereq_matches_use requires CPANTS DB setup by L<Module::CPANTS::ProcessCPAN>.
-is_prereq really requires information of prereq of other modules but prereq_matches_use only needs mappings between modules and dists.
-So, this module query the mappings to MetaCPAN by using L<MetaCPAN::API::Tiny>.
+In L<Module::CPANTS::Analyse>, C<prereq_matches_use> requires CPANTS DB setup by L<Module::CPANTS::ProcessCPAN>. C<is_prereq> really requires information of prereq of other modules but C<prereq_matches_use> only needs mappings between modules and dists. So, this module query the mappings to MetaCPAN by using L<MetaCPAN::API::Tiny>.
 
-For default configuration, indicators are treated as follows:
+Recently, L<Module::CPANTS::Analyse> has been changed much. For actual available indicators, please consult C<Module::CPANTS::Kwalitee::*> documentation. For default configuration, indicators are treated as follows:
 
 =over 4
 
+=item NOTES
+
+=over 4
+
+=item B<(+)>
+
+No longer available for L<Module::CPANTS::Analyse> 0.88 or 0.90+.
+
+=item B<(++)>
+
+No longer available for L<Module::CPANTS::Analyse> 0.90+.
+
+=item B<(+++)>
+
+No longer available for L<Module::CPANTS::Analyse> 0.88 or 0.90+, moved to L<Module::CPANTS::SiteKwalitee|https://github.com/cpants/Module-CPANTS-SiteKwalitee>.
+
+=item B<(++++)>
+
+No longer available for L<Module::CPANTS::Analyse> 0.88 or 0.90+, moved to L<Module::CPANTS::SiteKwalitee|https://github.com/cpants/Module-CPANTS-SiteKwalitee> but supported by this module.
+
+=back
+
 =item Available indicators in core
 
 =over 4
@@ -453,7 +468,7 @@ has_tests
 
 =item *
 
-buildtool_not_executable
+buildtool_not_executable B<(++)>
 
 =item *
 
@@ -461,7 +476,7 @@ metayml_is_parsable
 
 =item *
 
-metayml_has_license
+metayml_has_license B<(optional for 0.88 or 0.90+)>
 
 =item *
 
@@ -469,19 +484,19 @@ metayml_conforms_to_known_spec
 
 =item *
 
-proper_libs
+proper_libs B<(for 0.87 or 0.89)>
 
 =item *
 
-no_pod_errors
+no_pod_errors B<(+)>
 
 =item *
 
-has_working_buildtool
+has_working_buildtool B<(+)>
 
 =item *
 
-has_better_auto_install
+has_better_auto_install B<(+)>
 
 =item *
 
@@ -489,15 +504,15 @@ use_strict
 
 =item *
 
-valid_signature
+valid_signature B<(+++)>
 
 =item *
 
-has_humanreadable_license
+has_humanreadable_license B<(for 0.87 or 0.89)> | has_human_redable_license B<(for 0.88 or 0.90+)>
 
 =item *
 
-no_cpants_errors
+no_cpants_errors B<(+)>
 
 =back
 
@@ -511,7 +526,7 @@ has_tests_in_t_dir
 
 =item *
 
-has_example
+has_example B<(+)>
 
 =item *
 
@@ -527,7 +542,7 @@ metayml_declares_perl_version
 
 =item *
 
-prereq_matches_use
+prereq_matches_use B<(++++)>
 
 =item *
 
@@ -535,11 +550,11 @@ use_warnings
 
 =item *
 
-has_test_pod
+has_test_pod B<(+)>
 
 =item *
 
-has_test_pod_coverage
+has_test_pod_coverage B<(+)>
 
 =back
 
@@ -553,19 +568,19 @@ has_test_pod_coverage
 
 =item *
 
-extractable
+extractable B<(+)>
 
 =item *
 
-extracts_nicely
+extracts_nicely B<(+)>
 
 =item *
 
-has_version
+has_version B<(+)>
 
 =item *
 
-has_proper_version
+has_proper_version B<(+)>
 
 =back
 
@@ -579,7 +594,7 @@ manifest_matches_dist
 
 =item *
 
-no_generated_files
+no_generated_files B<(++)>
 
 =back
 
@@ -589,18 +604,38 @@ no_generated_files
 
 =over 4
 
+=item Can not apply already unpacked dist
+
+=over 4
+
+=item *
+
+proper_libs B<(for 0.88 or 0.90+)>
+
+=back
+
 =item Needs CPANTS DB
 
 =over 4
 
 =item *
 
-is_prereq
+is_prereq B<(+++)>
 
 =back
 
 =back
 
+=item Indicators with special note in experimental
+
+=over 4
+
+=item *
+
+build_prereq_matches_use B<(++++)>
+
+=back
+
 =back
 
 =head1 SEE ALSO
